@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -327,7 +326,7 @@ static const char *
 fr_command_alz_get_packages (FrCommand  *comm,
 			     const char *mime_type)
 {
-	return "unalz";
+	return PACKAGES ("unalz");
 }
 
 
