@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
@@ -675,11 +674,6 @@ fr_command_rar_handle_error (FrCommand   *comm,
 			break;
 		}
 
-		if (strstr (line, "wrong password") != NULL) {
-			error->type = FR_PROC_ERROR_ASK_PASSWORD;
-			break;
-		}
-
 		if (strncmp (line, "Unexpected end of archive", 25) == 0) {
 			/* FIXME: handle this type of errors at a higher level when the freeze is over. */
 		}
